.cli[data-v-d4ce5ac7]{background-color:var(--ac-terminal-bg);border-radius:5px;padding:10px;color:var(--ac-terminal-text);font-family:monospace;overflow-x:hidden;word-break:break-all;white-space:pre-wrap;max-width:100%}.cli .copy-button[data-v-d4ce5ac7]{position:absolute;top:4px;right:4px;z-index:10;color:#71717a;display:flex;align-items:center;justify-content:center;padding:4px}.cli .copy-button[data-v-d4ce5ac7]:hover{color:var(--ac-terminal-text)}[data-v-31a81fb9]:root{--abstra-main-color-dark: #343b46}.execution-context-container[data-v-31a81fb9]{border-radius:5px;padding:10px;color:var(--ac-text-primary);width:100%;font-family:monospace;max-height:600px;overflow:auto;border:1px solid var(--ac-border-primary)}.tree[data-v-31a81fb9] .ant-tree-node-content-wrapper{-webkit-user-select:auto;user-select:auto}.ask-to-ai[data-v-31a81fb9]{display:flex;gap:6px;align-items:center;cursor:pointer;color:var(--ac-brand-primary)}.ask-to-ai.disabled[data-v-31a81fb9]{cursor:not-allowed;opacity:.5}
