import{v as a,I as c,C as u}from"./jwt-decode.esm-CuqABuF0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="688933c5-1be5-46b7-872c-198a84de65e5",e._sentryDebugIdIdentifier="sentry-dbid-688933c5-1be5-46b7-872c-198a84de65e5")}catch{}})();function l(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(i){return Object.getOwnPropertyDescriptor(r,i).enumerable}))),n.forEach(function(i){f(e,i,r[i])})}return e}function f(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var o=function(t,r){var n=l({},t,r.attrs);return a(c,l({},n,{icon:u}),null)};o.displayName="CloseCircleOutlined";o.inheritAttrs=!1;export{o as C};
//# sourceMappingURL=CloseCircleOutlined-Cu7nmCMs.js.map
