import{e as d,b as n,f as i,g as u,O as o,P as r,k as c,h as y}from"./jwt-decode.esm-CuqABuF0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6d8ee417-13b7-4e1d-93a9-dd319c0622be",e._sentryDebugIdIdentifier="sentry-dbid-6d8ee417-13b7-4e1d-93a9-dd319c0622be")}catch{}})();const p=d({__name:"ScrollArea",props:{innerClass:{},outerClass:{},outerStyle:{},innerStyle:{}},setup(e){const t=e,s=n(()=>t.outerStyle?{position:"relative",...t.outerStyle}:{position:"relative"}),a=n(()=>({position:"absolute",inset:0,overflow:"auto",...t.innerStyle??{}}));return(l,f)=>(u(),i("div",{style:r(s.value),class:o(e.outerClass)},[c("div",{style:r(a.value),class:o(e.innerClass)},[y(l.$slots,"default")],6)],6))}});export{p as _};
//# sourceMappingURL=ScrollArea.vue_vue_type_script_setup_true_lang-3f9N1cx7.js.map
