import{O as l}from"./workspaceStore-Ba1E_U_-.js";import{e as c,W as f,f as u,v as n,w as o,p as a,ao as b,T as _,q as r,t as i,l as s,g as p}from"./jwt-decode.esm-CuqABuF0.js";import"./userStore-gUmjnlUt.js";import"./runnerData-DQ3Ht7os.js";import"./url-Cjn6hAfg.js";import"./colorHelpers-CyiO3ixI.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2e1bbdfb-8bd1-4945-981c-9599efb61322",e._sentryDebugIdIdentifier="sentry-dbid-2e1bbdfb-8bd1-4945-981c-9599efb61322")}catch{}})();const D=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new l().loginCallback()}),(t,d)=>(p(),u("div",null,[n(a(b),null,{default:o(()=>[r(i(a(s).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(a(_),null,{default:o(()=>[r(i(a(s).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLoginCallback-C1vGmyKt.js.map
