import{i}from"./url-Cjn6hAfg.js";import"./jwt-decode.esm-CuqABuF0.js";import{i as u}from"./colorHelpers-CyiO3ixI.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c1c77c97-05d6-4ea8-a45e-d37d3e452731",e._sentryDebugIdIdentifier="sentry-dbid-c1c77c97-05d6-4ea8-a45e-d37d3e452731")}catch{}})();function r(e,a,s){return i(a)?a:s==="player"?`/_assets/${e}`:`/_editor/api/assets/${a}`}const n="#414a58",t="#FFFFFF",_="#000000",l="DM Sans",c="Untitled Project",o={value:"en"};function p(e){return{id:e.id,path:e.path,theme:e.workspace.theme??t,brandName:e.workspace.brand_name??null,title:e.title,isInitial:e.is_initial,isLocal:e.is_local??!1,startMessage:e.start_message??null,endMessage:e.end_message??null,errorMessage:e.error_message??null,timeoutMessage:e.timeout_message??null,startButtonText:e.start_button_text??null,logoUrl:e.workspace.logo_url,mainColor:e.workspace.main_color??n,fontFamily:e.workspace.font_family??l,autoStart:e.auto_start??!1,runtimeType:"form",language:e.workspace.language??o.value,sidebar:e.workspace?.sidebar??[]}}function b(e){const a=e.theme??t;return{name:e.name||c,fontColor:e.font_color||_,sidebar:e.sidebar||[],brandName:e.brand_name||"",fontFamily:e.font_family||l,logoUrl:e.logo_url?r("logo",e.logo_url,"player"):null,mainColor:e.main_color||n,theme:u(a)?a:r("background",a,"player"),language:e.language||o.value}}export{n as D,l as a,o as b,t as c,r as m,p as r,b as w};
//# sourceMappingURL=runnerData-DQ3Ht7os.js.map
