import{aP as l,f as r,g as s,j as c,k as i,h as n,e as u,M as p,n as f,p as a}from"./jwt-decode.esm-CuqABuF0.js";import{O as _}from"./OmniChat-xHrdSN0t.js";import{u as h}from"./omniChatStore-B1l9Wl0z.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b3c715fa-77d7-43dd-ae00-a59e6dcecea4",e._sentryDebugIdIdentifier="sentry-dbid-b3c715fa-77d7-43dd-ae00-a59e6dcecea4")}catch{}})();const m={},y={class:"project-layout"},b={key:0,class:"project-navbar"},j={class:"project-body"},g={key:0,class:"project-sidebar"},I={class:"project-content"},k={key:1,class:"project-chat"};function v(e,o){return s(),r("div",y,[e.$slots.navbar?(s(),r("header",b,[n(e.$slots,"navbar",{},void 0,!0)])):c("",!0),i("section",j,[e.$slots.sidebar?(s(),r("aside",g,[n(e.$slots,"sidebar",{},void 0,!0)])):c("",!0),i("main",I,[n(e.$slots,"content",{},void 0,!0)]),e.$slots.chat?(s(),r("aside",k,[n(e.$slots,"chat",{},void 0,!0)])):c("",!0)])])}const D=l(m,[["render",v],["__scopeId","data-v-2a5a05cf"]]),O=u({__name:"ConsoleOmniChat",props:{projectId:{}},setup(e){const o=e,t=h();return p(()=>o.projectId,d=>t.init("console",d),{immediate:!0}),(d,$)=>a(t).controller&&a(t).repository?(s(),f(_,{key:0,"ai-chat-repository":a(t).repository,controller:a(t).controller,environment:{origin:"console",projectId:o.projectId},"show-console-suggestions":!0},null,8,["ai-chat-repository","controller","environment"])):c("",!0)}});export{D as P,O as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang-D5frEENw.js.map
