import{v as c,I as d,ah as o}from"./jwt-decode.esm-CuqABuF0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="37582d98-47d3-45bf-983d-0d9bc07bb254",e._sentryDebugIdIdentifier="sentry-dbid-37582d98-47d3-45bf-983d-0d9bc07bb254")}catch{}})();function a(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(i){return Object.getOwnPropertyDescriptor(n,i).enumerable}))),r.forEach(function(i){u(e,i,n[i])})}return e}function u(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var l=function(t,n){var r=a({},t,n.attrs);return c(d,a({},r,{icon:o}),null)};l.displayName="ExclamationCircleOutlined";l.inheritAttrs=!1;export{l as E};
//# sourceMappingURL=ExclamationCircleOutlined-CMxAwnGM.js.map
