.background-theme[data-v-b383d566]{background-repeat:no-repeat;background-size:cover;background-position:center}.sidebar[data-v-b383d566]{position:absolute;top:48px;bottom:0;left:-15rem;width:15rem;padding:12px;display:flex;flex-direction:column;align-items:flex-start;gap:2rem;background:var(--ac-bg-primary);box-sizing:border-box;z-index:2;transition:.6s}.sidebar.open[data-v-b383d566]{left:0;box-shadow:4px 8px 4px var(--ac-shadow-color)}.sidebar .sidebar-content[data-v-b383d566]{display:flex;flex-direction:column;overflow:auto;width:100%}.sidebar .sidebar-content .item[data-v-b383d566]{min-height:unset;cursor:pointer;padding:1rem;box-sizing:border-box;display:flex;gap:1rem;align-items:center;justify-content:flex-start;border-radius:4px}.sidebar .sidebar-content .item .item-title[data-v-b383d566]{font-family:var(--font-family);font-style:normal;font-weight:500;font-size:14px;-webkit-user-select:none;user-select:none;line-height:20px;letter-spacing:.1px;color:var(--ac-text-secondary)}.sidebar .sidebar-content .item[data-v-b383d566]:hover,.sidebar .sidebar-content .item[data-v-b383d566]:active{background:var(--ac-bg-hover)}.sidebar .sidebar-content .item:active .item-title[data-v-b383d566]{color:var(--color-main)}.sidebar .sidebar-content .item.disabled[data-v-b383d566]{opacity:.8;pointer-events:none}.sidebar .sidebar-content .active[data-v-b383d566]{background:var(--ac-bg-hover);cursor:default}.sidebar .sidebar-content .active .item-title[data-v-b383d566]{color:var(--color-main)}.background-theme[data-v-ba7e0153]{background-repeat:no-repeat;background-size:cover;background-position:center}.navbar[data-v-ba7e0153]{display:flex;justify-content:space-between;align-items:center;box-shadow:0 0 100px var(--ac-shadow-color);height:48px;padding:0 16px;width:100%;box-sizing:border-box;z-index:2}.navbar.background[data-v-ba7e0153]{background:var(--ac-bg-primary)}.left-side[data-v-ba7e0153]{display:flex;flex-direction:row;align-items:center;gap:20px;overflow:hidden}.logo-image[data-v-ba7e0153]{height:30px;width:auto;object-fit:contain}.brand[data-v-ba7e0153]{display:flex;flex-direction:row;align-items:center;justify-content:center;gap:10px;overflow:hidden}.brand .brand-name[data-v-ba7e0153]{color:var(--ac-text-secondary);font-weight:400;font-size:16px;line-height:24px}.right-side[data-v-ba7e0153]{display:flex;gap:20px;align-items:center}.signed-email[data-v-ba7e0153]{display:flex;align-items:center;font-size:14px;line-height:20px;color:var(--ac-text-secondary)}.sidebar-menu-icon[data-v-ba7e0153]{cursor:pointer;width:24px;height:24px;flex-shrink:0;border-radius:8px}@media screen and (min-width:1200px){.sidebar-menu-icon.dash[data-v-ba7e0153]:not(.desktop){display:none}}.sidebar-menu-icon.dash.mobile[data-v-ba7e0153]{display:unset}
