import{C as m,T as b}from"./router-C-Pd0gHD.js";import{e as u,b as f,l as d,n as i,j as y,g as r,p as s,w as t,B as c,q as l,t as o,v as p,T as _}from"./jwt-decode.esm-CuqABuF0.js";import{A as k}from"./index-DyxOBHke.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="6a42d38a-c923-44ca-b29e-1cb6a8180065",e._sentryDebugIdIdentifier="sentry-dbid-6a42d38a-c923-44ca-b29e-1cb6a8180065")}catch{}})();const M=u({__name:"BillingAlert",props:{organizationId:{},billingMetadata:{}},setup(e){const a=e,n=f(()=>a.billingMetadata?.messageCTA??d.translate("i18n_billingalert_contact_us")),g=()=>{m.showNewMessage(d.translate("i18n_billingalert_help_message")),b.billingAlertCtaClicked(a.organizationId,n.value)};return(C,w)=>e.billingMetadata?.message?(r(),i(s(k),{key:0,type:"error"},{message:t(()=>[p(s(_),{type:"secondary"},{default:t(()=>[l(o(e.billingMetadata?.message),1)]),_:1})]),action:t(()=>[e.billingMetadata?.messageLink?(r(),i(s(c),{key:0,type:"primary",target:"_blank",href:e.billingMetadata.messageLink},{default:t(()=>[l(o(n.value),1)]),_:1},8,["href"])):(r(),i(s(c),{key:1,type:"primary",onClick:g},{default:t(()=>[l(o(n.value),1)]),_:1}))]),_:1})):y("",!0)}});export{M as _};
//# sourceMappingURL=BillingAlert.vue_vue_type_script_setup_true_lang-CjWWjbkW.js.map
