import{O as l}from"./workspaceStore-Ba1E_U_-.js";import{e as c,W as f,f as u,v as o,w as n,p as a,ao as _,T as p,q as r,t as s,l as d,g as b}from"./jwt-decode.esm-CuqABuF0.js";import"./userStore-gUmjnlUt.js";import"./runnerData-DQ3Ht7os.js";import"./url-Cjn6hAfg.js";import"./colorHelpers-CyiO3ixI.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3d41f7e5-f659-45cf-b716-8f10d4927c97",e._sentryDebugIdIdentifier="sentry-dbid-3d41f7e5-f659-45cf-b716-8f10d4927c97")}catch{}})();const D=c({__name:"OidcLogoutCallback",setup(e){return f(async()=>{await new l().logoutCallback()}),(t,i)=>(b(),u("div",null,[o(a(_),null,{default:n(()=>[r(s(a(d).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(a(p),null,{default:n(()=>[r(s(a(d).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLogoutCallback-Cu_JvGPf.js.map
