.project-layout[data-v-2a5a05cf]{display:flex;flex-direction:column;height:100%;overflow:hidden}.project-layout .project-navbar[data-v-2a5a05cf]{flex-shrink:0;width:100%;border-bottom:1px solid var(--ac-border-primary)}.project-layout .project-body[data-v-2a5a05cf]{display:flex;flex-grow:1;overflow:hidden}.project-layout .project-body .project-sidebar[data-v-2a5a05cf]{flex-shrink:0;overflow-y:auto}.project-layout .project-body .project-content[data-v-2a5a05cf]{flex-grow:1;overflow:auto}.project-layout .project-body .project-chat[data-v-2a5a05cf]{flex-shrink:0}
