import{N as m}from"./Navbar-r-d-y3ET.js";import{e as d,an as u,b as a,l,a9 as f,f as _,g as b,v as n,k as y,aP as I}from"./jwt-decode.esm-CuqABuF0.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang--Tg12rpp.js";import"./constants-BofaUPsW.js";import"./PhCaretDown.vue-DVSevI0U.js";import"./os-CmEo06OM.js";import"./router-C-Pd0gHD.js";import"./ts.worker-D20Caz_K.js";import"./organization-CFugdneJ.js";import"./tables-BHu5fUrG.js";import"./string-CcKlk4eJ.js";import"./keyboard-BHQ1f0Fx.js";import"./projectStore-CgnhEzHY.js";import"./project-D3XwUmzI.js";import"./organizationSwitcher-C3nwECnr.js";import"./cascaderStore-CChdaozc.js";import"./folder-Bovb-6rt.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-C00m5pGO.js";import"./member-CO0IVq7z.js";import"./index-BKQgjwGL.js";import"./index-DSwmPxSG.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-D3OgPvEV.js";import"./PhNotePencil.vue-BxjF5wCU.js";import"./PhSignOut.vue-NYcczSAG.js";import"./index-MrLvTX6y.js";import"./index-BtAPplff.js";import"./PhPlus.vue-BHUak-3-.js";import"./omniChatStore-B1l9Wl0z.js";import"./contracts.generated-BpQhIfeJ.js";import"./runnerData-DQ3Ht7os.js";import"./url-Cjn6hAfg.js";import"./colorHelpers-CyiO3ixI.js";import"./uuid-BEs58qNE.js";import"./PhCopySimple.vue-Dp1BNiIR.js";import"./index-BN39JQSp.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e1e66a50-820b-4e4f-a79b-b01c2a80fc3c",e._sentryDebugIdIdentifier="sentry-dbid-e1e66a50-820b-4e4f-a79b-b01c2a80fc3c")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(e){const o=u(),s=a(()=>!!o.params.projectId),p=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),c=a(()=>{const t=o.params.projectId,i=o.params.tableId,r=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:p.value};if(r)return{organizationId:r}});return(t,i)=>{const r=f("RouterView");return b(),_("div",v,[n(m,{"use-cascader":!0,"cascader-props":c.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",g,[n(r)])])}}}),ao=I(w,[["__scopeId","data-v-62f8634d"]]);export{ao as default};
//# sourceMappingURL=ConsoleLayout-tFhuTcml.js.map
