import{e as i,b as o,f as a,j as r,O as l,t as g,bc as u,g as s,aP as f}from"./jwt-decode.esm-CuqABuF0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b4a3255d-163c-4dc2-9fe8-2e07e8c6be17",e._sentryDebugIdIdentifier="sentry-dbid-b4a3255d-163c-4dc2-9fe8-2e07e8c6be17")}catch{}})();const m={class:"logo"},b=["src","alt"],y=i({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){u(d=>({v4521d904:n.value}));const t=e,n=o(()=>t.size==="small"?"24px":t.size==="large"?"80px":"50px"),c=o(()=>`${t.brandName} Logo`);return(d,p)=>(s(),a("div",m,[e.imageUrl?(s(),a("img",{key:0,class:"logo-img",src:e.imageUrl,alt:c.value},null,8,b)):r("",!0),e.hideText?r("",!0):(s(),a("span",{key:1,class:l(e.size)},g(e.brandName),3))]))}}),_=f(y,[["__scopeId","data-v-8f34aac0"]]);export{_ as L};
//# sourceMappingURL=Logo-a_c-G9th.js.map
