import{y as i,A as c,D as f}from"./jwt-decode.esm-CuqABuF0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="9f226008-f368-4f04-9505-e7694abe2024",e._sentryDebugIdIdentifier="sentry-dbid-9f226008-f368-4f04-9505-e7694abe2024")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:d,TimePicker:m,QuarterPicker:o,RangePicker:a}=i(c),u=f(n,{WeekPicker:t,MonthPicker:r,YearPicker:d,RangePicker:a,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(r.name,r),e.component(t.name,t),e.component(o.name,o),e)});export{u as D,r as M,o as Q,a as R,t as W};
//# sourceMappingURL=dayjs-DT31FEHw.js.map
