import{P as g}from"./PlayerNavbar-C9Pzp3Xg.js";import{e as _,an as i,r as h,b,f as k,n as y,j as v,k as w,p as n,v as L,a9 as C,aj as I,g as c,aP as N}from"./jwt-decode.esm-CuqABuF0.js";import{u as V}from"./workspaceStore-Ba1E_U_-.js";import"./userStore-gUmjnlUt.js";import"./metadata-CuML2xSN.js";import"./PhHouse.vue-Sq9l6Kng.js";import"./PhMagnifyingGlass.vue-CQ15jXyW.js";import"./PhWebhooksLogo.vue-BEnXcRcJ.js";import"./LoadingOutlined-D2cr0m31.js";import"./PhSignOut.vue-NYcczSAG.js";import"./index-BtAPplff.js";import"./runnerData-DQ3Ht7os.js";import"./url-Cjn6hAfg.js";import"./colorHelpers-CyiO3ixI.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="019c7a3b-30f2-458b-b405-5fb133072468",o._sentryDebugIdIdentifier="sentry-dbid-019c7a3b-30f2-458b-b405-5fb133072468")}catch{}})();const B={class:"main-container"},D={class:"content"},P=_({__name:"Main",setup(o){const e=I(),t=V(),p=i().path,a=h(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},d=()=>{e.push({name:"playerLogin"})},m=b(()=>!!i().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return c(),k("div",B,[n(t).state.workspace?(c(),y(g,{key:0,"current-path":n(p),"hide-login":m.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:d,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",D,[L(f)])])}}}),J=N(P,[["__scopeId","data-v-f095bece"]]);export{J as default};
//# sourceMappingURL=Main-CQUrNEsT.js.map
