import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-DAzItxh6.js";import{e as i,f as u,v as d,p as n,aj as m,an as f,g as l,aP as _}from"./jwt-decode.esm-CuqABuF0.js";import{u as b}from"./workspaceStore-Ba1E_U_-.js";import"./OTPInput-C0pHFTkX.js";import"./Logo-a_c-G9th.js";import"./string-CcKlk4eJ.js";import"./CircularLoading-yzaaHzVQ.js";import"./index-DyxOBHke.js";import"./userStore-gUmjnlUt.js";import"./runnerData-DQ3Ht7os.js";import"./url-Cjn6hAfg.js";import"./colorHelpers-CyiO3ixI.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="20b0459f-b728-4ce4-8fe1-034552bad1e2",e._sentryDebugIdIdentifier="sentry-dbid-20b0459f-b728-4ce4-8fe1-034552bad1e2")}catch{}})();const g={class:"runner"},y=i({__name:"Login",setup(e){const o=m(),r=f(),t=b(),c=async()=>{const{redirect:a,...s}=r.query;if(a){await o.push({path:a,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>(l(),u("div",g,[d(p,{"logo-url":n(t).state.workspace?.logoUrl??void 0,"brand-name":n(t).state.workspace?.brandName,locale:n(t).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(y,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-BoiKJuBe.js.map
