import{b as n}from"./router-C-Pd0gHD.js";import"./jwt-decode.esm-CuqABuF0.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="54a76c14-4243-4710-acce-5260dbeca61c",r._sentryDebugIdIdentifier="sentry-dbid-54a76c14-4243-4710-acce-5260dbeca61c")}catch{}})();class i{async create(e){return n.post(`organizations/${e.organizationId}/members`,{email:e.email,folderIds:e.folderIds})}async delete(e){return n.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return n.get(`organizations/${e}/members`)}async get(e,t){return n.get(`organizations/${e}/members/${t}`)}async update(e,t,a){return n.patch(`organizations/${e}/members/${t}`,a)}}export{i as M};
//# sourceMappingURL=member-CO0IVq7z.js.map
