import{A as n}from"./index-BuNHV0sx.js";import{e as o,b as r,f as a,j as c,O as f,v as d,p as l,g as p,aP as i}from"./jwt-decode.esm-CuqABuF0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="e59ed37e-dc2b-486f-b2b7-65fc3440c3f1",e._sentryDebugIdIdentifier="sentry-dbid-e59ed37e-dc2b-486f-b2b7-65fc3440c3f1")}catch{}})();const u=o({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=r(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(b,m)=>e.stepsInfo?(p(),a("nav",{key:0,class:f(["p-steps",{"full-screen":!e.isPreview}])},[d(l(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):c("",!0)}}),v=i(u,[["__scopeId","data-v-58fdd395"]]);export{v as S};
//# sourceMappingURL=Steps-B8CWfzxA.js.map
