import{aP as r,f as o,h as s,k as n,j as d,g as a}from"./jwt-decode.esm-CuqABuF0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="cf56b706-4ba7-49ae-97b6-ba033333bbcb",e._sentryDebugIdIdentifier="sentry-dbid-cf56b706-4ba7-49ae-97b6-ba033333bbcb")}catch{}})();const c={},i={class:"base-layout"},f={class:"base-middle"},b={class:"content"},l={class:"left"},u={key:0,class:"base-footer"},_={key:0};function y(e,t){return a(),o("div",i,[s(e.$slots,"sidebar",{},void 0,!0),n("section",f,[s(e.$slots,"navbar",{},void 0,!0),n("section",b,[n("section",l,[s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(a(),o("section",u,[s(e.$slots,"footer",{},void 0,!0)])):d("",!0)]),e.$slots.chat?(a(),o("section",_,[s(e.$slots,"chat",{},void 0,!0)])):d("",!0)])])])}const g=r(c,[["render",y],["__scopeId","data-v-a9f53d25"]]);export{g as B};
//# sourceMappingURL=BaseLayout-Cp607RCB.js.map
