import{v as f,I as o,ag as c}from"./jwt-decode.esm-CuqABuF0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3f892985-5fc8-41db-89f1-cd6657cc7db6",e._sentryDebugIdIdentifier="sentry-dbid-3f892985-5fc8-41db-89f1-cd6657cc7db6")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(d){return Object.getOwnPropertyDescriptor(n,d).enumerable}))),r.forEach(function(d){u(e,d,n[d])})}return e}function u(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var a=function(t,n){var r=i({},t,n.attrs);return f(o,i({},r,{icon:c}),null)};a.displayName="LoadingOutlined";a.inheritAttrs=!1;export{a as L};
//# sourceMappingURL=LoadingOutlined-D2cr0m31.js.map
