import{C as e,_ as p}from"./View.vue_vue_type_script_setup_true_lang--4YzLDwB.js";import{e as i,n,g as m,p as a}from"./jwt-decode.esm-CuqABuF0.js";import{u as s}from"./projectStore-CgnhEzHY.js";import"./router-C-Pd0gHD.js";import"./ts.worker-D20Caz_K.js";import"./fetch-BGWsR7Pn.js";import"./tables-BHu5fUrG.js";import"./string-CcKlk4eJ.js";import"./SaveButton-BUG_l7_M.js";import"./ExclamationCircleOutlined-CMxAwnGM.js";import"./CrudView-BHryVBYL.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-CgCER6dv.js";import"./constants-BofaUPsW.js";import"./url-Cjn6hAfg.js";import"./PhDotsThreeVertical.vue-DRWxiRIS.js";import"./index-MrLvTX6y.js";import"./asyncComputed-Ba-hGgzE.js";import"./omniChatStore-B1l9Wl0z.js";import"./contracts.generated-BpQhIfeJ.js";import"./runnerData-DQ3Ht7os.js";import"./colorHelpers-CyiO3ixI.js";import"./uuid-BEs58qNE.js";import"./PhCopySimple.vue-Dp1BNiIR.js";import"./PhPencil.vue-DE1An_rS.js";import"./useCodebaseEvents-DR3Kflua.js";import"./index-DyxOBHke.js";import"./project-D3XwUmzI.js";import"./organizationSwitcher-C3nwECnr.js";import"./organization-CFugdneJ.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="510ae12c-494f-4283-ac33-0d8fae7ab9a9",o._sentryDebugIdIdentifier="sentry-dbid-510ae12c-494f-4283-ac33-0d8fae7ab9a9")}catch{}})();const J=i({__name:"EnvVars",setup(o){const r=s(),t=new e(r.projectId);return(c,f)=>(m(),n(p,{"env-var-repository":a(t),mode:"console"},null,8,["env-var-repository"]))}});export{J as default};
//# sourceMappingURL=EnvVars-Bb5wYLhl.js.map
