.toggle-btn-active[data-v-54bc952a] button,.toggle-btn-active[data-v-54bc952a] button:hover{background-color:var(--ac-bg-hover)!important}.execution-card[data-v-54bc952a]{border-radius:8px;margin-bottom:12px;border:1px solid var(--ac-border-primary);overflow:hidden;background-color:var(--ac-bg-primary);box-shadow:0 1px 2px 0 var(--ac-shadow-color)}.execution-card[data-v-54bc952a]:hover{border-color:var(--ac-border-secondary)}.execution-header[data-v-54bc952a]{display:flex;align-items:center;justify-content:space-between;width:100%;gap:16px}.execution-header-left[data-v-54bc952a]{display:flex;align-items:center;gap:12px;min-width:0}.status-dot[data-v-54bc952a]{width:10px;height:10px;border-radius:50%;flex-shrink:0}.status-spinner[data-v-54bc952a]{width:14px;height:14px;display:flex;align-items:center;justify-content:center;flex-shrink:0;color:var(--ac-brand-link);font-size:14px}.status-dot.finished[data-v-54bc952a]{background:var(--ac-color-success)}.status-dot.failed[data-v-54bc952a]{background:var(--ac-color-error)}.status-dot.abandoned[data-v-54bc952a]{background:var(--ac-color-warning)}.execution-info[data-v-54bc952a]{display:flex;flex-direction:column;min-width:0}.execution-stage[data-v-54bc952a]{font-weight:500;font-size:14px;color:var(--ac-text-primary);white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.execution-meta[data-v-54bc952a]{font-size:12px;color:var(--ac-text-tertiary);font-family:ui-monospace,SFMono-Regular,SF Mono,Menlo,Monaco,Liberation Mono,monospace}.execution-time[data-v-54bc952a]{font-size:12px;color:var(--ac-text-tertiary);white-space:nowrap;flex-shrink:0;margin-right:8px}.execution-actions-trigger[data-v-54bc952a]{display:flex;align-items:center;justify-content:center;width:28px;height:28px;border-radius:6px;cursor:pointer;color:var(--ac-text-disabled);transition:all .15s}.execution-actions-trigger[data-v-54bc952a]:hover{background:var(--ac-bg-tertiary);color:var(--ac-text-secondary)}[data-v-54bc952a] .copy-logs-btn:hover{color:var(--ac-brand-primary)!important;background:transparent!important}[data-v-54bc952a] .ant-tabs-tab-active .copy-logs-btn{color:var(--ac-brand-primary)}[data-v-54bc952a] .execution-card>.ant-collapse-header{padding:12px 16px!important;align-items:center!important}[data-v-54bc952a] .execution-card>.ant-collapse-content>.ant-collapse-content-box{padding:16px!important}.execution-card[data-v-54bc952a]:last-child{border-radius:8px;border:1px solid var(--ac-border-primary)}
