const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-C1vGmyKt.js","assets/workspaceStore-Ba1E_U_-.js","assets/jwt-decode.esm-CuqABuF0.js","assets/jwt-decode-CA6P2R_N.css","assets/userStore-gUmjnlUt.js","assets/runnerData-DQ3Ht7os.js","assets/url-Cjn6hAfg.js","assets/colorHelpers-CyiO3ixI.js","assets/OidcLogoutCallback-Cu_JvGPf.js","assets/Login-BoiKJuBe.js","assets/Login.vue_vue_type_script_setup_true_lang-DAzItxh6.js","assets/OTPInput-C0pHFTkX.js","assets/OTPInput-DkitIIgo.css","assets/Logo-a_c-G9th.js","assets/Logo-D2kepPyK.css","assets/string-CcKlk4eJ.js","assets/CircularLoading-yzaaHzVQ.js","assets/CircularLoading-BiyobKo3.css","assets/index-DyxOBHke.js","assets/Login-D3Bo1XNf.css","assets/Login-CobhrWJT.css","assets/Main-CQUrNEsT.js","assets/PlayerNavbar-C9Pzp3Xg.js","assets/metadata-CuML2xSN.js","assets/PhHouse.vue-Sq9l6Kng.js","assets/PhMagnifyingGlass.vue-CQ15jXyW.js","assets/PhWebhooksLogo.vue-BEnXcRcJ.js","assets/LoadingOutlined-D2cr0m31.js","assets/PhSignOut.vue-NYcczSAG.js","assets/index-BtAPplff.js","assets/PlayerNavbar-CeGdx3sX.css","assets/Main-DqPmGmnC.css","assets/Home-tsch0C9Z.js","assets/Watermark-C71KUByt.js","assets/constants-BofaUPsW.js","assets/Watermark-Fl_4jwe9.css","assets/PhArrowSquareOut.vue-Bf0hTWcW.js","assets/index-DSwmPxSG.js","assets/Home-C1q_HTgM.css","assets/Error-D08A3oZt.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-DhmfrzG6.js","assets/logo-BiWG9_W5.js","assets/Error-CIbhyrKS.css","assets/Form-D65PUTKT.js","assets/FormRunner-CsccYVBP.js","assets/Steps-B8CWfzxA.js","assets/index-BuNHV0sx.js","assets/Steps-D24tH1sk.css","assets/FormRunner-Cr_m7D0_.css","assets/redirect-E-d4puVN.js","assets/asyncComputed-Ba-hGgzE.js","assets/uuid-BEs58qNE.js","assets/Form-CshGBPDC.css"])))=>i.map(i=>d[i]);
import{c as u,a as d,_ as t,u as l}from"./jwt-decode.esm-CuqABuF0.js";import{u as p}from"./userStore-gUmjnlUt.js";import{a as _}from"./workspaceStore-Ba1E_U_-.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cf5accf6-aeb8-4ec9-818d-b0c15c139299",e._sentryDebugIdIdentifier="sentry-dbid-cf5accf6-aeb8-4ec9-818d-b0c15c139299")}catch{}})();const h=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-C1vGmyKt.js"),__vite__mapDeps([0,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-Cu_JvGPf.js"),__vite__mapDeps([8,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-BoiKJuBe.js"),__vite__mapDeps([9,10,2,3,1,4,5,6,7,11,12,13,14,15,16,17,18,19,20])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-CQUrNEsT.js"),__vite__mapDeps([21,22,4,2,3,1,5,6,7,23,24,25,26,27,28,29,30,31])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-tsch0C9Z.js"),__vite__mapDeps([32,23,24,2,3,25,26,33,1,4,5,6,7,34,35,36,37,27,38])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-D08A3oZt.js"),__vite__mapDeps([39,40,41,13,2,3,14,34,1,4,5,6,7,37,42])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-D65PUTKT.js"),__vite__mapDeps([43,4,2,3,44,10,1,5,6,7,11,12,13,14,15,16,17,18,19,45,46,47,33,34,35,48,49,50,51,52])),meta:{hideLogin:!0}}]}],i=u({history:d("/"),routes:h,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),f=e=>async(a,o)=>{if(l(a,o),a.meta.allowUnauthenticated)return;const r=p();r.loadJWT();const c=await _(a.path),{redirect:s,...m}=a.query;switch(c.status){case"ALLOWED":break;case"UNAUTHORIZED":{const n=r.email;r.removeJWT(),await e.push({name:"playerLogin",query:{...m,redirect:s||a.path,reauth:n?"true":void 0,email:n||void 0},params:a.params});break}case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};i.beforeEach(f(i));export{h as a,f as g,i as r};
//# sourceMappingURL=router-C6a8G52J.js.map
