.authorize[data-v-57fe5408]{display:flex;align-items:center;justify-content:center;height:100vh;text-align:center}.authorize .content[data-v-57fe5408]{display:flex;flex-direction:column;gap:1rem;align-items:center}
