import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-DhmfrzG6.js";import{B as y}from"./BaseLayout-Cp607RCB.js";import{e as l,Y as _,a6 as v,aP as u,aK as b,aL as g,g as f,f as h,k as a,P as n,W as w,aj as S,n as k,w as s,an as B,v as i,p as I}from"./jwt-decode.esm-CuqABuF0.js";import{u as L}from"./editor-CgjLnGh9.js";import{A as P}from"./index-BN39JQSp.js";import"./logo-BiWG9_W5.js";import"./Logo-a_c-G9th.js";import"./ts.worker-D20Caz_K.js";import"./workspaceStore-Ba1E_U_-.js";import"./userStore-gUmjnlUt.js";import"./runnerData-DQ3Ht7os.js";import"./url-Cjn6hAfg.js";import"./colorHelpers-CyiO3ixI.js";import"./useCodebaseEvents-DR3Kflua.js";import"./contracts.generated-BpQhIfeJ.js";import"./router-C6a8G52J.js";import"./constants-BofaUPsW.js";import"./linters-C1jEfXpT.js";import"./asyncComputed-Ba-hGgzE.js";import"./index-MrLvTX6y.js";import"./index-BtAPplff.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="06a504fd-e128-4350-bd80-33522231fc42",e._sentryDebugIdIdentifier="sentry-dbid-06a504fd-e128-4350-bd80-33522231fc42")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...v(r)}}}),x={class:"v-spinner"};function D(e,r,o,d,c,p){return b((f(),h("div",x,[a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u($,[["render",D],["__scopeId","data-v-224007fd"]]),R={class:"content"},j=l({__name:"ProjectLogin",setup(e){const r=B(),o=S(),d=L();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){o.push({name:"error"});return}await d.createLogin(t).then(c),o.push({name:"editor"})}),(t,z)=>(f(),k(y,null,{navbar:s(()=>[i(I(P),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:s(()=>[i(m)]),_:1})]),content:s(()=>[a("div",R,[i(K)])]),_:1}))}}),re=u(j,[["__scopeId","data-v-c9eeae4b"]]);export{re as default};
//# sourceMappingURL=ProjectLogin-BDeN3zT8.js.map
