import{u as r}from"./userStore-gUmjnlUt.js";import{W as n}from"./PlayerConfigProvider-DRr52D-b.js";import{u as c}from"./workspaceStore-Ba1E_U_-.js";import{e as f,M as d,n as i,j as m,p as o,w as u,v as p,a9 as l,g as w}from"./jwt-decode.esm-CuqABuF0.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="cf78f0cc-e25d-48e2-86ae-bac98f9e98bd",t._sentryDebugIdIdentifier="sentry-dbid-cf78f0cc-e25d-48e2-86ae-bac98f9e98bd")}catch{}})();const C=f({__name:"App",setup(t){document.documentElement.dataset.theme="light";const a=r(),e=c();return e.actions.fetch(),d(()=>a.jwt,e.actions.fetch),(_,g)=>{const s=l("RouterView");return o(e).state.workspace?(w(),i(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:u(()=>[p(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):m("",!0)}}});export{C as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang-Dl-qXFM-.js.map
