@charset "UTF-8";.breadcrumb-skeleton[data-v-2937d650]{display:inline-flex;align-items:center}.breadcrumb-skeleton[data-v-2937d650] .ant-skeleton .ant-skeleton-title{margin:0;height:20px}.breadcrumb-cascader[data-v-2937d650]{display:inline-flex;align-items:center;gap:4px;cursor:pointer}.breadcrumb-cascader[data-v-2937d650] .ant-cascader{width:auto!important;min-width:0!important}.breadcrumb-cascader[data-v-2937d650] .ant-cascader .ant-select-selector{border:none!important;background:transparent!important;box-shadow:none!important;padding:0!important;height:auto!important;min-width:0!important}.breadcrumb-cascader[data-v-2937d650] .ant-cascader .ant-select-selection-item{padding:0!important}.breadcrumb-cascader[data-v-2937d650] .ant-cascader .ant-select-arrow{display:none}.dropdown-icon[data-v-2937d650]{font-size:10px;color:var(--ac-text-tertiary)}.edit-icon[data-v-2937d650]{font-size:14px;color:var(--ac-brand-primary);cursor:pointer;transition:transform .2s}.edit-icon[data-v-2937d650]:hover{transform:scale(1.1)}.edit-input[data-v-2937d650]{width:200px}.ant-cascader-menu-item[title=Organizações],.ant-cascader-menu-item[title=Organizations],.ant-cascader-menu-item[title=Pastas],.ant-cascader-menu-item[title=Folders],.ant-cascader-menu-item[title=Projetos],.ant-cascader-menu-item[title=Projects],.ant-cascader-menu-item[title=Tabelas],.ant-cascader-menu-item[title=Tables]{display:flex!important;justify-content:space-between!important;align-items:center!important;font-size:11px!important;font-weight:600!important;text-transform:uppercase!important;letter-spacing:.05em!important;color:var(--ac-text-tertiary)!important;background-color:var(--ac-bg-secondary)!important;padding:6px 12px!important;border-bottom:1px solid var(--ac-border-primary)!important;cursor:pointer!important}.ant-cascader-menu-item[title=Organizações]:after,.ant-cascader-menu-item[title=Organizations]:after,.ant-cascader-menu-item[title=Pastas]:after,.ant-cascader-menu-item[title=Folders]:after,.ant-cascader-menu-item[title=Projetos]:after,.ant-cascader-menu-item[title=Projects]:after,.ant-cascader-menu-item[title=Tabelas]:after,.ant-cascader-menu-item[title=Tables]:after{content:"+";font-size:16px;font-weight:500;color:var(--ac-text-tertiary);margin-left:auto;padding-left:12px}.ant-cascader-menu-item[title=Organizações]:hover,.ant-cascader-menu-item[title=Organizations]:hover,.ant-cascader-menu-item[title=Pastas]:hover,.ant-cascader-menu-item[title=Folders]:hover,.ant-cascader-menu-item[title=Projetos]:hover,.ant-cascader-menu-item[title=Projects]:hover,.ant-cascader-menu-item[title=Tabelas]:hover,.ant-cascader-menu-item[title=Tables]:hover{background-color:var(--ac-bg-hover)!important}.ant-cascader-menu{background-color:var(--ac-bg-elevated)!important}.ant-cascader-menu-item{color:var(--ac-text-primary)}.ant-cascader-menu-item.ant-cascader-menu-item-active{background-color:var(--ac-bg-selected);color:var(--ac-brand-primary);font-weight:600}.ant-cascader-menu-item:hover{background-color:var(--ac-bg-hover)}.editable-item[data-v-e67e9e4c]{display:inline-flex;align-items:center;gap:4px;cursor:pointer}.editable-item .edit-icon[data-v-e67e9e4c]{opacity:0;transition:opacity .2s}.editable-item:hover .edit-icon[data-v-e67e9e4c]{opacity:.6}.edit-input[data-v-e67e9e4c]{width:200px}.organization-switcher[data-v-7986e786]{cursor:pointer;display:inline-flex;align-items:center;gap:4px;color:inherit;font-weight:400;transition:color .3s,opacity .3s}.organization-switcher[data-v-7986e786]:hover{color:var(--ac-brand-primary);opacity:1}.organization-switcher .icon[data-v-7986e786]{font-size:10px;margin-top:2px}.organization-switcher .edit-icon[data-v-7986e786]{font-size:14px;cursor:pointer;color:var(--ac-brand-primary);transition:transform .2s}.organization-switcher .edit-icon[data-v-7986e786]:hover{transform:scale(1.1)}.organization-edit-input[data-v-7986e786]{width:200px}.create-item[data-v-7986e786]{display:flex;align-items:center;gap:8px;color:var(--ac-brand-primary)}.project-switcher[data-v-9354451c]{cursor:pointer;display:inline-flex;align-items:center;gap:4px;color:inherit;font-weight:400;transition:color .3s,opacity .3s}.project-switcher[data-v-9354451c]:hover{color:var(--ac-brand-primary);opacity:1}.project-switcher .icon[data-v-9354451c]{font-size:10px;margin-top:2px}.project-switcher .edit-icon[data-v-9354451c]{font-size:14px;cursor:pointer;color:var(--ac-brand-primary);transition:transform .2s}.project-switcher .edit-icon[data-v-9354451c]:hover{transform:scale(1.1)}.project-edit-input[data-v-9354451c]{width:200px}.project-link[data-v-9354451c]{color:inherit;text-decoration:none;display:block}.project-link[data-v-9354451c]:hover{color:inherit}.logo-container[data-v-f8583945]{display:flex;align-items:center;gap:8px;cursor:pointer;margin-right:16px}.logo[data-v-f8583945]{height:20px}.logo-text[data-v-f8583945]{font-weight:600;font-size:16px}.extra[data-v-f8583945]{display:flex;align-items:center;height:40px;justify-content:center;gap:12px}
