import{z as d}from"./jwt-decode.esm-CuqABuF0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e3ed511d-96af-45c0-82f4-01ece359ee3d",e._sentryDebugIdIdentifier="sentry-dbid-e3ed511d-96af-45c0-82f4-01ece359ee3d")}catch{}})();function h(e){return d.string().email().safeParse(e).success}function p(e){return e.trim().toLowerCase().normalize("NFD").replace(/[\u0300-\u036f]/g,"")}function w(e){return e.charAt(0).toUpperCase()+e.slice(1)}function m(e,t,r=!1,n=!0,l=!1,a=!0){const s=(n?e.toLocaleLowerCase():e).normalize("NFD").replace(/[\u0300-\u036f]/g,""),o=`a-zA-Z0-9${l?"/":""}${a?"-":""}`,c=new RegExp(`[^${o}]`,"g"),u=s.replace(c,"_"),f=r?u:u.replace(/_+/g,"_");return t?f:f.replace(/_$/,"")}function z(e){const r=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),n=/[a-z0-9]+/g;return r.match(n)?.join("-")??""}function C(e,t){if(e.length===0||t.length===0)return!1;const r=e.toLowerCase(),n=t.toLowerCase();return r.split("").reduce((a,i)=>{if(a===!1)return!1;const s=a[a.length-1]??null;if(s===null){const o=n.indexOf(i);return o===-1?!1:[o]}else{const c=n.slice(s+1).indexOf(i);return c===-1?!1:[...a,s+1+c]}},[])}function b(e){let t=0;for(let r=0;r<e.length;r++){const n=e.charCodeAt(r);t=(t<<5)-t+n,t=t&t}return t}export{p as a,z as b,w as c,C as f,b as h,h as i,m as n};
//# sourceMappingURL=string-CcKlk4eJ.js.map
