import{B as c}from"./BaseLayout-Cp607RCB.js";import{C as f}from"./ContentLayout-DhjtGp0B.js";import{e as l,an as _,b as i,M as g,a9 as b,n as r,g as s,w as u,v as y,j as w}from"./jwt-decode.esm-CuqABuF0.js";import{_ as v}from"./BillingAlert.vue_vue_type_script_setup_true_lang-CjWWjbkW.js";import{u as h}from"./projectsStore-H8ncVaPA.js";import"./router-C-Pd0gHD.js";import"./ts.worker-D20Caz_K.js";import"./index-DyxOBHke.js";import"./member-CO0IVq7z.js";import"./organization-CFugdneJ.js";import"./project-D3XwUmzI.js";import"./tables-BHu5fUrG.js";import"./string-CcKlk4eJ.js";import"./folder-Bovb-6rt.js";import"./ant-design-BW5BPqF1.js";import"./cascaderStore-CChdaozc.js";import"./organizationSwitcher-C3nwECnr.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="91331ffe-3a9f-48b4-9ea0-69ee5253b660",t._sentryDebugIdIdentifier="sentry-dbid-91331ffe-3a9f-48b4-9ea0-69ee5253b660")}catch{}})();const q=l({__name:"Organization",setup(t){const e=_(),o=h(),a=i(()=>e.params.organizationId);g(a,n=>{n&&!o.fetchedState&&o.fetchState(n)},{immediate:!0});const d=i(()=>o.fetchedState?.organization),m=i(()=>d.value?.billingMetadata);return(n,z)=>{const p=b("RouterView");return s(),r(c,null,{content:u(()=>[y(f,null,{default:u(()=>[m.value?(s(),r(v,{key:0,"billing-metadata":m.value,"organization-id":a.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(p,{key:a.value}))]),_:1})]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization-Cjp29p6D.js.map
