(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="caab8388-a952-4ad9-a34d-629661667e4c",e._sentryDebugIdIdentifier="sentry-dbid-caab8388-a952-4ad9-a34d-629661667e4c")}catch{}})();function r(e){return new RegExp("^(("+e.join(")|(")+"))\\b","i")}var t=["package","message","import","syntax","required","optional","repeated","reserved","default","extensions","packed","bool","bytes","double","enum","float","string","int32","int64","uint32","uint64","sint32","sint64","fixed32","fixed64","sfixed32","sfixed64","option","service","rpc","returns"],i=r(t),a=new RegExp("^[_A-Za-z¡-][_A-Za-z0-9¡-]*");function d(e){return e.eatSpace()?null:e.match("//")?(e.skipToEnd(),"comment"):e.match(/^[0-9\.+-]/,!1)&&(e.match(/^[+-]?0x[0-9a-fA-F]+/)||e.match(/^[+-]?\d*\.\d+([EeDd][+-]?\d+)?/)||e.match(/^[+-]?\d+([EeDd][+-]?\d+)?/))?"number":e.match(/^"([^"]|(""))*"/)||e.match(/^'([^']|(''))*'/)?"string":e.match(i)?"keyword":e.match(a)?"variable":(e.next(),null)}const u={name:"protobuf",token:d,languageData:{autocomplete:t}};export{u as protobuf};
//# sourceMappingURL=protobuf-BIBuwHQB.js.map
