import{b as r}from"./router-C-Pd0gHD.js";import"./jwt-decode.esm-CuqABuF0.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="03a57d18-6fc7-47a6-a71c-669ca8a28ccc",n._sentryDebugIdIdentifier="sentry-dbid-03a57d18-6fc7-47a6-a71c-669ca8a28ccc")}catch{}})();class i{async list(e){return(await r.get(`organizations/${e}/folders`)).sort((t,s)=>t.name.localeCompare(s.name))}async create(e){return r.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async checkNameAvailability(e,a){return r.post(`organizations/${e}/folders/name-available`,{folderName:a})}async delete(e,a){return r.delete(`organizations/${e}/folders/${a}`)}async update(e,a){return r.patch(`organizations/${e}/folders/${a.id}/`,{name:a.name,memberIds:a.memberIds})}}export{i as F};
//# sourceMappingURL=folder-Bovb-6rt.js.map
