import{_ as a}from"./logo-BiWG9_W5.js";import{L as r}from"./Logo-a_c-G9th.js";import{e as o,n as s,p as d,g as i}from"./jwt-decode.esm-CuqABuF0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c5a1aab2-0963-4e2f-83d1-e1496cf337d5",e._sentryDebugIdIdentifier="sentry-dbid-c5a1aab2-0963-4e2f-83d1-e1496cf337d5")}catch{}})();const u=o({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(t,n)=>(i(),s(r,{"image-url":d(a),"brand-name":"Abstra","hide-text":e.hideText,size:e.size??"small"},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang-DhmfrzG6.js.map
