import{i as h}from"./metadata-CuML2xSN.js";import{W as w}from"./Watermark-C71KUByt.js";import{F as b}from"./PhArrowSquareOut.vue-Bf0hTWcW.js";import{e as v,b as x,r as C,f,j as D,p as e,v as p,w as s,H as u,n as r,q as y,t as _,l as I,b3 as g,R as z,a1 as F,aj as j,g as a,O as B,$ as H,aP as L}from"./jwt-decode.esm-CuqABuF0.js";import{u as N}from"./workspaceStore-Ba1E_U_-.js";import{C as P}from"./index-DSwmPxSG.js";import{L as S}from"./LoadingOutlined-D2cr0m31.js";import"./PhHouse.vue-Sq9l6Kng.js";import"./PhMagnifyingGlass.vue-CQ15jXyW.js";import"./PhWebhooksLogo.vue-BEnXcRcJ.js";import"./constants-BofaUPsW.js";import"./userStore-gUmjnlUt.js";import"./runnerData-DQ3Ht7os.js";import"./url-Cjn6hAfg.js";import"./colorHelpers-CyiO3ixI.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[n]="099b1185-f8ec-4113-89e0-51f72053cde1",o._sentryDebugIdIdentifier="sentry-dbid-099b1185-f8ec-4113-89e0-51f72053cde1")}catch{}})();const T={key:0,class:"home-container"},V=v({__name:"Home",setup(o){const n=j(),i=N(),d=x(()=>i.state.workspace?.sidebar.filter(c=>c.id!=="home")||[]),l=C(null),k=async(c,m)=>{l.value=m,await n.push({path:`/${c}`}),l.value=null};return(c,m)=>e(i).state.workspace?(a(),f("div",T,[p(e(u),{vertical:"",gap:"large",class:"cards-container"},{default:s(()=>[d.value.length===0?(a(),r(e(g),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:s(()=>[y(_(e(I).translate("i18n_home_no_forms_available")),1)]),_:1})):(a(!0),f(z,{key:1},F(d.value,t=>(a(),r(e(P),{key:t.id,class:B(["form-card",{loading:l.value===t.id}]),"body-style":{cursor:"pointer"},onClick:W=>k(t.path,t.id)},{default:s(()=>[p(e(u),{gap:"large",align:"center",justify:"space-between"},{default:s(()=>[(a(),r(H(e(h)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(g),{style:{"font-size":"18px","font-weight":"500"}},{default:s(()=>[y(_(t.name),1)]),_:2},1024),l.value!==t.id?(a(),r(e(b),{key:0,size:"20"})):(a(),r(e(S),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(w,{class:"watermark","page-id":"home",locale:e(i).state.workspace.language},null,8,["locale"])])):D("",!0)}}),ee=L(V,[["__scopeId","data-v-132e66ff"]]);export{ee as default};
//# sourceMappingURL=Home-tsch0C9Z.js.map
