import{aT as r,aU as n,aa as o,aV as p,aW as c,aX as d,aY as f,aZ as m,a_ as u,a$ as s,b0 as g,b1 as l,b2 as y}from"./jwt-decode.esm-CuqABuF0.js";import{b,s as w,g as _}from"./workspaceStore-Ba1E_U_-.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang-Dl-qXFM-.js";import{r as i}from"./router-C6a8G52J.js";import"./userStore-gUmjnlUt.js";import"./runnerData-DQ3Ht7os.js";import"./url-Cjn6hAfg.js";import"./colorHelpers-CyiO3ixI.js";import"./PlayerConfigProvider-DRr52D-b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fa6fa8a7-1456-42a3-8fa3-f4a952288e14",e._sentryDebugIdIdentifier="sentry-dbid-fa6fa8a7-1456-42a3-8fa3-f4a952288e14")}catch{}})();class I{static init(){setInterval(()=>{b("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const e=await _(),t=r(),a=n({render:()=>o(h)});p.init(),c(a,i,e),I.init(),a.use(i),a.use(t),a.use(d),a.mount("#app"),a.component("VSelect",f),a.component("Markdown",m),a.component("Message",u),s(a,g),s(a,l),s(a,y)})();
//# sourceMappingURL=player-DJamx4qt.js.map
