import{e as d,b as s,f as l,g as i,k as r,h as c,P as u,O as a,aP as f}from"./jwt-decode.esm-CuqABuF0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="10f6199d-6ce6-4211-91cd-426ca8480214",e._sentryDebugIdIdentifier="sentry-dbid-10f6199d-6ce6-4211-91cd-426ca8480214")}catch{}})();const y=d({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean},flexLayout:{type:Boolean},innerPadding:{}},setup(e){const n=e,t=s(()=>({...n.innerPadding&&{padding:n.innerPadding}}));return(o,g)=>(i(),l("div",{class:a(["content-layout",{"no-padding":e.noPadding}])},[r("div",{class:a(["centered-layout",{"full-width":e.fullWidth,"flex-layout":e.flexLayout}]),style:u(t.value)},[c(o.$slots,"default",{},void 0,!0)],6)],2))}}),m=f(y,[["__scopeId","data-v-00e066e8"]]);export{m as C};
//# sourceMappingURL=ContentLayout-DhjtGp0B.js.map
