(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9b655bef-2259-4e63-ad67-51a2b8e66d02",e._sentryDebugIdIdentifier="sentry-dbid-9b655bef-2259-4e63-ad67-51a2b8e66d02")}catch{}})();function c(e){for(var n={},r=e.split(" "),t=0;t<r.length;++t)n[r[t]]=!0;return n}var s=c("absolute and array asm begin case const constructor destructor div do downto else end file for function goto if implementation in inherited inline interface label mod nil not object of operator or packed procedure program record reintroduce repeat self set shl shr string then to type unit until uses var while with xor as class dispinterface except exports finalization finally initialization inline is library on out packed property raise resourcestring threadvar try absolute abstract alias assembler bitpacked break cdecl continue cppdecl cvar default deprecated dynamic enumerator experimental export external far far16 forward generic helper implements index interrupt iocheck local message name near nodefault noreturn nostackframe oldfpccall otherwise overload override pascal platform private protected public published read register reintroduce result safecall saveregisters softfloat specialize static stdcall stored strict unaligned unimplemented varargs virtual write"),d={null:!0},a=/[+\-*&%=<>!?|\/]/;function f(e,n){var r=e.next();if(r=="#"&&n.startOfLine)return e.skipToEnd(),"meta";if(r=='"'||r=="'")return n.tokenize=p(r),n.tokenize(e,n);if(r=="("&&e.eat("*"))return n.tokenize=l,l(e,n);if(r=="{")return n.tokenize=u,u(e,n);if(/[\[\]\(\),;\:\.]/.test(r))return null;if(/\d/.test(r))return e.eatWhile(/[\w\.]/),"number";if(r=="/"&&e.eat("/"))return e.skipToEnd(),"comment";if(a.test(r))return e.eatWhile(a),"operator";e.eatWhile(/[\w\$_]/);var t=e.current().toLowerCase();return s.propertyIsEnumerable(t)?"keyword":d.propertyIsEnumerable(t)?"atom":"variable"}function p(e){return function(n,r){for(var t=!1,i,o=!1;(i=n.next())!=null;){if(i==e&&!t){o=!0;break}t=!t&&i=="\\"}return(o||!t)&&(r.tokenize=null),"string"}}function l(e,n){for(var r=!1,t;t=e.next();){if(t==")"&&r){n.tokenize=null;break}r=t=="*"}return"comment"}function u(e,n){for(var r;r=e.next();)if(r=="}"){n.tokenize=null;break}return"comment"}const b={name:"pascal",startState:function(){return{tokenize:null}},token:function(e,n){if(e.eatSpace())return null;var r=(n.tokenize||f)(e,n);return r=="comment"||r=="meta",r},languageData:{indentOnInput:/^\s*[{}]$/,commentTokens:{block:{open:"(*",close:"*)"}}}};export{b as pascal};
//# sourceMappingURL=pascal-qb3dRuE3.js.map
