import{e as _,aj as p,an as m,l as s,n as f,g as c,w as d,f as g,R as y,a1 as v,v as k,p as n,k as w,t as I}from"./jwt-decode.esm-CuqABuF0.js";import{u as T}from"./projectStore-CgnhEzHY.js";import{A as j,T as D}from"./index-DSwmPxSG.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="30be6592-07d1-4c37-ba31-bc46dc4c1d0d",e._sentryDebugIdIdentifier="sentry-dbid-30be6592-07d1-4c37-ba31-bc46dc4c1d0d")}catch{}})();const N=_({__name:"TablesTabs",setup(e){const a=p(),r=m(),i=String(r.name),u=T(),o=[{label:s.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:s.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:s.translate("i18n_tablestabs_run_sql"),value:"sql"}],b=l=>{a.push({name:String(l),params:{projectId:u.projectId}})};return(l,S)=>(c(),f(n(D),{"active-key":n(i),options:o,"onUpdate:activeKey":b},{default:d(()=>[(c(),g(y,null,v(o,t=>k(n(j),{key:t.value,name:t.value},{tab:d(()=>[w("span",null,I(t.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{N as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-CFn3IKm-.js.map
